==> og1_dashboard-0.0.6.tar.gz: lib/src/widgets/search_widget.dart <==
import 'package:flutter/material.dart';

class SearchWidget extends StatefulWidget {
  final TextEditingController searchController;
  final String hintText;

  const SearchWidget({
    Key? key,
    required this.searchController,
    required this.hintText,
  }) : super(key: key);

  @override
  _SearchWidgetState createState() => _SearchWidgetState();
}

class _SearchWidgetState extends State<SearchWidget> {
  @override
  Widget build(BuildContext context) {
    const TextStyle styleActive = TextStyle(color: Colors.black);
    const TextStyle styleHint = TextStyle(color: Colors.black54);
    TextStyle style = styleHint;
    bool searchControllerIsEmpty = true;
    widget.searchController.addListener(() {
      searchControllerIsEmpty = widget.searchController.text.isEmpty;
      style = searchControllerIsEmpty ? styleHint : styleActive;
    });

    return Container(
      height: 42,
      margin: const EdgeInsets.fromLTRB(16, 16, 16, 16),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: Colors.white,
        border: Border.all(color: Colors.black26),
      ),
      padding: const EdgeInsets.symmetric(horizontal: 8),
      child: TextField(
        controller: widget.searchController,
        decoration: InputDecoration(
          icon: Icon(Icons.search, color: style.color),
          suffixIcon: searchControllerIsEmpty
              ? null
              : GestureDetector(
                  child: Icon(Icons.close, color: style.color),
                  onTap: () {
                    widget.searchController.clear();
                    FocusScope.of(context).requestFocus(FocusNode());
                  },
                ),
          hintText: widget.hintText,
          hintStyle: style,
          border: InputBorder.none,
        ),
        style: style,
      ),
    );
  }
}

==> og1_dashboard-0.0.14.tar.gz: lib/src/widgets/search_widget.dart <==
import 'package:flutter/material.dart';

class SearchWidget extends StatefulWidget {
  final TextEditingController searchController;
  final String? hintSearch;

  const SearchWidget({
    Key? key,
    required this.searchController,
    this.hintSearch = 'Search...',
  }) : super(key: key);

  @override
  _SearchWidgetState createState() => _SearchWidgetState();
}

class _SearchWidgetState extends State<SearchWidget> {
  @override
  Widget build(BuildContext context) {
    const TextStyle styleActive = TextStyle(color: Colors.black);
    const TextStyle styleHint = TextStyle(color: Colors.black54);
    TextStyle style = styleHint;
    bool searchControllerIsEmpty = true;
    widget.searchController.addListener(() {
      searchControllerIsEmpty = widget.searchController.text.isEmpty;
      style = searchControllerIsEmpty ? styleHint : styleActive;
    });

    return Container(
      height: 42,
      margin: const EdgeInsets.fromLTRB(16, 16, 16, 16),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: Colors.white,
        border: Border.all(color: Colors.black26),
      ),
      padding: const EdgeInsets.symmetric(horizontal: 8),
      child: TextField(
        controller: widget.searchController,
        decoration: InputDecoration(
          icon: Icon(Icons.search, color: style.color),
          suffixIcon: searchControllerIsEmpty
              ? null
              : GestureDetector(
                  child: Icon(Icons.close, color: style.color),
                  onTap: () {
                    widget.searchController.clear();
                    FocusScope.of(context).requestFocus(FocusNode());
                  },
                ),
          hintText: widget.hintSearch,
          hintStyle: style,
          border: InputBorder.none,
        ),
        style: style,
      ),
    );
  }
}
